#!/bin/bash
#SBATCH --job-name="inner-astrocyte 200ns production run, zteselko"
#SBATCH --partition=defq
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=48
#SBATCH -t 10:00:00

source /data/apps/go.sh
module load gcc/9.3.0
module load namd/2.14-smp

#NODELIST=$SLURM_JOBID.nodes

#JOBNODES=$(scontrol show hostname $SLURM_JOB_NODELIST)

#echo group main > $NODELIST
#for nodes  in $JOBNODES ; do
#        echo host $nodes >> $NODELIST
#done

### Note: use one core to drive the job  (+ppn + (ntasks -1)

COMMAND="charmrun ++ppn 47 ++local `which namd2` +idlepoll +setcpuaffinity "

echo $COMMAND





# Set Run Length per file
simt=500000

krun=1

if [ -e start.time ] 
then
	start=(`cat start.time`)
else
	start=0                  
fi

# Create a new input file
rm -f dyn.inp
cat dyn-1.inp > dyn.inp
echo "firsttimestep     $start; " >> dyn.inp
cat dyn-2.inp >> dyn.inp

one="one"
echo $one > test.file
echo $one

# Execution of the script
$COMMAND dyn.inp > dyn.out

echo $one >> test.file
echo $one

okay=true
# TEST FOR EXISTENCE, THEN NONZERO LENGTH OF OUTPUT FILES
if [[ -e dyn.coor && -e dyn.dcd ]] 
then
	tsz=`/bin/ls -s dyn.dcd | awk '{print $1}'`
	nrm=`grep 'WallClock' dyn.out | wc -l`
	nrm1=`grep 'ERROR: ' dyn.out | wc -l`
 
	echo $tsz >> test.file
	echo $tsz
	echo $nrm >> test.file
	echo $nrm
	
	if [[ $tsz -gt 0 && $nrm -eq 1 && $nrm1 -lt 1 ]]
		then
		echo "success"
		# SUCCESSFUL RUN; COPY RESTART FILE
		#  cp dyn.res dyn.rea
		# DETERMINE RUN NUMBER
		if [ -e next.seqno ] 
 		then
			i=(`cat next.seqno`)
		else
			i=1
		fi
	
		# Change the new Start Time
		start=$((start + simt))
                echo "success"
		echo $start > start.time
		
		# ENABLE/DISABLE ANALYSIS EVERY 2ND RUN
		#  if ( 0 == $i % 2 ) qsub -l nodes=1 chk.csh
		# NUMBER THE OUTPUT FILES; CHANGE EXTENSIONS TO SUIT APPLICATION
		for fil in  out coor xsc xst vel dcd 
		do
			mv dyn.$fil dyn$i.$fil
		done
		
		cp dyn$i.xsc dyn.xsc
		cp dyn$i.coor dyn.coor
		cp dyn$i.vel dyn.vel
		gzip dyn$i.out dyn$i.coor dyn$i.xsc dyn$i.vel dyn$i.xst
		# CONDITIONAL END CHECK
		if [ -e last.seqno ] 
		then
			l=(`cat last.seqno`)
			if [ $i -eq $l ] 
			then
				i=$((i+1))
				echo $i > next.seqno 
				exit
			fi
		fi
	
		# SUBMIT THE NEXT JOB
		#  rm ~/namd.$PBS_JOBID
	
		i=$((i+1))
		echo $i > next.seqno
		./dyn.scr
		exit
	else
		# FILE DOESN'T EXIST
		okay=false
	fi

	# FILE DOESN'T EXIST
 	okay=false
fi

# TEST FOR CHARMM RUN FAILED; CREATE .ERR FILE WITH TIMESTAMP
if [ $okay = false ] 
then
	ts= `date +%m%d.%H%M`
	mv dyn.out dyn.err.$ts
fi

